// ===================================================================
// (C) Copyright IBM Corp. 2005, 2006 All Rights Reserved.
//                                                                           
// Licensed Materials - Property of IBM
//                                                          
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.
//              
// You may copy, modify, and distribute this sample program in any
// form without payment to IBM, for any purpose including developing,
// using, marketing or distributing programs that include or are
// derivative works of the sample program.
//                                                                           
// The sample program is provided to you on an "AS IS" basis, without
// warranty of any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES,
// EITHER EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Some jurisdictions do not allow for the exclusion or limitation of
// implied warranties, so the above limitations or exclusions may not
// apply to you. IBM shall not be liable for any damages you suffer as
// a result of using, modifying or distributing the sample program or
// its derivatives.
//===================================================================
package com.ibm.wbimonitor.samples.fileemitter.formatter;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Properties;

import org.eclipse.hyades.logging.events.cbe.CommonBaseEvent;
import org.eclipse.hyades.logging.events.cbe.ComponentIdentification;
import org.eclipse.hyades.logging.events.cbe.EventFactory;
import org.eclipse.hyades.logging.events.cbe.EventFactoryFactory;
import org.eclipse.hyades.logging.events.cbe.ExtendedDataElement;
import org.eclipse.hyades.logging.events.cbe.Situation;

import com.ibm.wbimonitor.samples.emitterframework.EventFormatter;
import com.ibm.wbimonitor.samples.emitterframework.exception.EventFormatFailedException;
import com.ibm.wbimonitor.samples.fileemitter.EventFileBean;

/*
 * This class implements the EventFormatter interface.
 */
public class CLAIMFormatterImpl implements EventFormatter {

    /*
     * This method implements the format interface of EventFormatter.
     */
    public CommonBaseEvent format( Object o ) throws EventFormatFailedException {

        CommonBaseEvent event = null;
        Properties eventData = null;

        eventData = ( (EventFileBean)o ).getFileContents( );

        EventFactory eventFactory = (EventFactory)EventFactoryFactory.createEventFactory( );
        event = eventFactory.createCommonBaseEvent( );

        event.setVersion( "1.0.1" );
        event.setCreationTimeAsLong( System.currentTimeMillis( ) );
        event.setExtensionName( "Claim" );

        ComponentIdentification componentId = eventFactory.createComponentIdentification( );
        componentId.setApplication( "DB2" );
        componentId.setComponent( "db2.exe" );
        componentId.setSubComponent( "db2syscs.exe" );
        componentId.setComponentType( "http://www.ibm.com/namespaces/db2" );
        componentId.setComponentIdType( "db2syscs.exe" );
        componentId.setLocation( "lycos" );
        componentId.setLocationType( "IPV4" );
        event.setSourceComponentId( componentId );

        Situation situation = eventFactory.createSituation( );
        situation.setAvailableSituation( "EXTERNAL", "NOT AVAILABLE", "STARTABLE", "FUNCTION_PROCESS" );
        event.setSituation( situation );

        ExtendedDataElement trig = event.addExtendedDataElement( "TRIGGER" );
        String eventAction = (String)eventData.getProperty( "EVENTACTION" );
        trig.setValuesAsString( eventAction );

        ExtendedDataElement id = event.addExtendedDataElement( "ID" );
        id.setValuesAsInt( Integer.parseInt( (String)eventData.getProperty( "ID" ) ) );

        if( !( "DELETE".equalsIgnoreCase( eventAction ) ) ) {
        	Date startDateAsDate = null;        	
        	try {
        		startDateAsDate = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss.SSS z").parse( (String)eventData.getProperty( "STARTDATE" ) );
        	}
        	catch( ParseException pe ) {
        		throw new EventFormatFailedException( "Unable to convert the specified string to a date format.", pe );        		
        	}
        	
            ExtendedDataElement name = event.addExtendedDataElement( "NAME" );
            name.setValuesAsString( (String)eventData.getProperty( "NAME" ) );
            ExtendedDataElement amount = event.addExtendedDataElement( "AMOUNT" );
            amount.setValuesAsFloat( new Float( (String)eventData.getProperty( "AMOUNT" ) ).floatValue( ) );
            ExtendedDataElement zipCode = event.addExtendedDataElement( "ZIPCODE" );
            zipCode.setValuesAsInt( new Integer( (String)eventData.getProperty( "ZIPCODE" ) ).intValue( ) );
            ExtendedDataElement startDate = event.addExtendedDataElement( "STARTDATE" );
            startDate.setValuesAsDateAsLong( startDateAsDate.getTime() );            
        }

        return event;
    }
}